@@ -45,7 +45,7 @@ JS
 
   context "matching file extensions" do
     it "matches .coffee files" do
-      expect(converter.matches(".coffee")).to be_true
+      expect(converter.matches(".coffee")).to be(true)
     end
   end
 
@@ -56,7 +56,7 @@ JS
   end
 
   context "converting CoffeeScript" do
-    it "produces CSS" do
+    it "produces JS" do
       expect(converter.convert(coffeescript_content)).to eql(js_content)
     end
   end
